#delim ;
version 11.0;
*
 Examples of regression of mpg with respect to weight
 in the auto data distributed with official Stata,
 using cubic spline models to estimate mean mpg levels
 at each reference weight,
 in full dataset and in even- and odd-numbered miodels.
 Graphics files generated:
 figseq7.eps, figseq8.eps.
 SSC packages used:
 bspline, descsave, parmest, keyby, eclplot, fvprevar, prodvars, fvregen, factext
*;

clear all;
set memory 1m;
set scheme rbn2mono;

*
 Input data
*;
sysuse auto, clear;
summ weight, de;

*
 Regression model without intercept
*;
flexcurv, xvar(weight) refpts(1760(616)4840) power(3)
  generate(sp_);
describe sp_*;
regress mpg sp_*, noconst nohead;
parmest, label list(parm label estimate min* max*, sepa(0))
  format(estimate min* max* %8.2f);

*
 Regression model with intercept
*;
flexcurv, xvar(weight) refpts(1760(616)4840) power(3)
  generate(esp_) base(1760);
describe esp_*;
regress mpg esp_*, nohead;
parmest, label omit list(parm label omit estimate min* max* p, sepa(0))
  format(estimate min* max* %8.2f p %-8.2g);

*
 Plot of effects
*;
tempfile df0;
descsave weight, do(`"`df0'"');
preserve;
parmest, label omit norestore;
gene weight=real(subinstr(subinstr(label,"Spline at ","",1),",","",.));
run `"`df0'"';
keyby weight, missing;
desc;
list;
eclplot estimate min* max* weight, hori
  estopts(msize(4)) ciopts(msize(6) lwidth(0.75))
  ylab(1760(616)4840) yscale(range(1452 5148))
  xline(0) xlab(-30(5)5) xtitle("Effect (with 95% CI) on: Mileage (mpg)")
  xsize(5) ysize(5);
graph export figseq7.eps, replace;
more;
restore;

*
 Regression model with separate slopes and intercepts
 for odd- and even-numbered models
*;
gene byte odd=mod(_n,2);
lab def odd 0 "Even" 1 "Odd";
lab val odd odd;
lab var odd "Oddness";
tab odd, m;
fvprevar ibn.odd, gene(a_);
flexcurv, xvar(weight) refpts(1760(616)4840) power(3)
  generate(b_) base(1760) labpref(weight@) labfmt(%8.0g);
prodvars a_*, rvarlist(b_*) gene(c_) lseparator(" & ");
desc a_* b_* c_*;
regress mpg a_* c_*, nohead noconst;
parmest, label omit list(parm label omit estimate min* max* p, sepa(0))
  format(estimate min* max* %8.2f p %-8.2g);

*
 Plot of oddness-stratified effects
*;
tempfile df1;
descsave odd weight, do(`"`df1'"', replace);
preserve;
parmest, label omit norestore;
split label, parse(" & ") gene(S_);
fvregen, from(S_1);
factext, from(S_2) parse(@);
run `"`df1'"';
drop S_*;
keyby odd weight, miss;
desc;
list, sepby(odd);
eclplot estimate min* max* weight, hori
  estopts(msize(4)) ciopts(msize(6) lwidth(0.5))
  by(odd)
  ylab(1760(616)4840) yscale(range(1452 5148))
  xline(0) xlab(-40(5)5) xtitle("Effect (with 95% CI) on: Mileage (mpg)")
  xsize(5) ysize(5);
graph export figseq8.eps, replace;
more;
restore;

exit;
