#delim ;
version 11.0;
*
 Input official Stata dataset auto
 and Stata datasets spparam1.dta and spxval1.dta.
 Create figures figseq1.eps and figseq2.eps
 for spline model
 of mpg with respect to weight.
 SSC packages used:
 scheme_rbn1mono, descsave, expgen, keyby, eclplot
*;

clear all;
set memory 2m;
set scheme rbn2mono;

*
 Input descriptive attributes for variable power.
*;
tempfile df0;
descsave power using spparam1.dta, do(`"`df0'"');

*
 Input auto data
 and expand it to have 1 obs per spline power per car model.
*;
sysuse auto, clear;
desc;
summ weight, de;
expgen =4, copyseq(power);
replace power=power-1;
run `"`df0'"';
keyby power foreign make;
local Ytit: var lab mpg;
local Xtit: var lab weight;
numlist "0(5)45";
local Ylabs "`r(numlist)'";
desc;

*
 Produce figure in figseq1.eps
 with plots of observed and fitted mpg values against weight
 for all 4 spline models
*;
preserve;
append using spxval1.dta, gene(obstype);
lab def obstype 0 "Observed value" 1 "Fitted value";
lab val obstype obstype;
lab var obstype "Observation type";
keyby power obstype foreign make weight, miss;
desc;
char list;
local refpoints "`_dta[refpoints]'";
scatter mpg weight, msym(circle_hollow) msize(1)
  || scatter mpghat weight, msym(circle) msize(0.125)
  || ,
  by(power, legend(off)) subtitle(, size(3))
  xlab(`refpoints', labsize(3)) xtitle("`Xtit'", size(3))
  ylab(`Ylabs', labsize(3)) ytitle("`Ytit'", size(3))
  xsize(5) ysize(5);
graph export figseq1.eps, replace;
more;
restore;

*
 Produce figure in figseq2.eps
 with plots of spline parameters and fitted mpg values against weight
 for all 4 spline models
*;
preserve;
clear;
use spparam1.dta, clear;
append using spxval1.dta, gene(obstype);
lab def obstype 0 "Parameter" 1 "Fitted value";
lab val obstype obstype;
lab var obstype "Observation type";
keyby power obstype weight;
desc;
char list;
local refpoints "`_dta[refpoints]'";
eclplot estimate min* max* weight,
  estopts(msize(2)) ciopts(msize(2) lwidth(0.25))
  addplot(scatter mpghat weight, msym(circle) msize(0.125))
  by(power, legend(off)) subtitle(, size(3))
  xlab(`refpoints', labsize(3)) xtitle("`Xtit'", size(3))
  ylab(`Ylabs', labsize(3)) ytitle("`Ytit'", size(3))
  xsize(5) ysize(5);
graph export figseq2.eps, replace;
more;
restore;

exit;
